#' Deductive Data Correction and Imputation
#' 
#' Use data validation restrictions to estimate missing values
#' or trace and repair certain errors.
#'
#'
#' @name deductive
#' @docType  package
#' @aliases deductive-package
#' @import methods
#' @import lintools
#' @import validate
#' @importFrom stringdist stringdist
#' @importFrom stats complete.cases 
#' @importFrom stats setNames
#' @useDynLib deductive, .registration=TRUE
"_PACKAGE"


